@@ -104,13 +104,20 @@ define([
             }
             // move to executed cell
             // CHROME: TODO:
-        } else if (vpConfig.extensionType === 'lab') {
+        } else if (vpConfig.extensionType === 'lab' || vpConfig.extensionType === 'lite') {
             var { NotebookActions } = require('@jupyterlab/notebook');
             var { signalToPromise } = require('@jupyterlab/coreutils');
             var notebookPanel = vpKernel.getLabNotebookPanel();
             if (notebookPanel && notebookPanel.sessionContext){
                 var sessionContext = notebookPanel.sessionContext;	
                 let sessionType = sessionContext.type;
+                if (vpConfig.extensionType === 'lite') {
+                    // check one more time for jupyter lite
+                    // - it returns 'notebook' when it's console
+                    if (notebookPanel.console !== undefined) {
+                        sessionType = 'console';
+                    }
+                }
                 if (sessionType === 'notebook') {
                     var notebook = notebookPanel.content;
                     var notebookModel = notebook.model;
@@ -133,6 +140,7 @@ define([
                     // move to executed cell
                     $(vpKernel.getLabNotebookPanel().content.activeCell.node)[0].scrollIntoView(true);
                 } else if (sessionType === 'console') {
+                    //TODO:LITE: console check needed
                     var labConsole = notebookPanel.content;
                     var widget = labConsole.widgets[0];
                     if (type === 'markdown') {
@@ -169,7 +177,7 @@ define([
      */
     var insertCells = function(type, commands, exec=true, sigText='') {
 
-        if (vpConfig.extensionType === 'lab') {
+        if (vpConfig.extensionType === 'lab' || vpConfig.extensionType === 'lite') {
             var { NotebookActions } = require('@jupyterlab/notebook');
             var notebookPanel = vpKernel.getLabNotebookPanel();
         }
@@ -239,10 +247,17 @@ define([
                             }, 300);
                     }
                 }
-            } else if (vpConfig.extensionType === 'lab') {
+            } else if (vpConfig.extensionType === 'lab' || vpConfig.extensionType === 'lite') {
                 if (notebookPanel && notebookPanel.sessionContext){ 
-                    var sessionContext = notebookPanel.sessionContext;	
+                    var sessionContext = notebookPanel.sessionContext; 
                     let sessionType = sessionContext.type;
+                    if (vpConfig.extensionType === 'lite') {
+                        // check one more time for jupyter lite
+                        // - it returns 'notebook' when it's console
+                        if (notebookPanel.console !== undefined) {
+                            sessionType = 'console';
+                        }
+                    }
                     if (sessionType === 'notebook') {
                         var notebook = notebookPanel.content;
                         var notebookModel = notebook.model;
@@ -282,7 +297,7 @@ define([
         } else if (vpConfig.extensionType === 'colab') {
             // CHROME: TODO:
 
-        } else if (vpConfig.extensionType === 'lab') {
+        } else if (vpConfig.extensionType === 'lab' || vpConfig.extensionType === 'lite') {
             // LAB: TODO:
             let activeCell = notebookPanel.content.activeCell;
             let activeCellTop = $(activeCell.node).position().top;
