@@ -83,7 +83,7 @@ define([
                     modelStep: 1,
                     step: [
                         { name: 'ml_dataSplit', label: 'Data Split', useApp: true },
-                        { name: 'ml_regression', label: 'Regressor', useApp: true },
+                        { name: 'ml_regression', label: 'Regressor', useApp: true, child: ['pp_fit', 'pp_predict'] },
                         { name: 'pp_fit', label: 'Fit' },
                         { name: 'pp_predict', label: 'Predict' },
                         { name: 'ml_evaluation', label: 'Evaluation', useApp: true, state: { modelType: 'rgs' } },
@@ -94,7 +94,7 @@ define([
                     modelStep: 1,
                     step: [
                         { name: 'ml_dataSplit', label: 'Data Split', useApp: true },
-                        { name: 'ml_classification', label: 'Classifier', useApp: true },
+                        { name: 'ml_classification', label: 'Classifier', useApp: true, child: ['pp_fit', 'pp_predict'] },
                         { name: 'pp_fit', label: 'Fit' },
                         { name: 'pp_predict', label: 'Predict' },
                         { name: 'ml_evaluation', label: 'Evaluation', useApp: true, state: { modelType: 'clf' } },
@@ -104,9 +104,10 @@ define([
                     label: 'Clustering',
                     modelStep: 0,
                     step: [
-                        { name: 'ml_clustering', label: 'Clustering', useApp: true },
+                        { name: 'ml_clustering', label: 'Clustering', useApp: true, child: ['pp_fit', 'pp_predict', 'pp_fit_predict', 'pp_transform'] },
                         { name: 'pp_fit', label: 'Fit' },
                         { name: 'pp_predict', label: 'Predict' },
+                        { name: 'pp_fit_predict', label: 'Fit and Predict' },
                         { name: 'pp_transform', label: 'Transform' },
                         { name: 'ml_evaluation', label: 'Evaluation', useApp: true, state: { modelType: 'cls' } },
                     ]
@@ -115,9 +116,10 @@ define([
                     label: 'Dimension Reduction',
                     modelStep: 0,
                     step: [
-                        { name: 'ml_dimensionReduction', label: 'Dimension Reduction', useApp: true },
+                        { name: 'ml_dimensionReduction', label: 'Dimension Reduction', useApp: true, child: ['pp_fit', 'pp_transform', 'pp_fit_transform'] },
                         { name: 'pp_fit', label: 'Fit' },
-                        { name: 'pp_transform', label: 'Transform' }
+                        { name: 'pp_transform', label: 'Transform' },
+                        { name: 'pp_fit_transform', label: 'Fit and Transform' },
                     ]
                 },
                 'gridSearch': {
@@ -125,7 +127,7 @@ define([
                     modelStep: 1,
                     step: [
                         { name: 'ml_dataSplit', label: 'Data Split', useApp: true },
-                        { name: 'ml_gridSearch', label: 'GridSearch', useApp: true },
+                        { name: 'ml_gridSearch', label: 'GridSearch', useApp: true, child: ['pp_fit', 'pp_predict'] },
                         { name: 'pp_fit', label: 'Fit' },
                         { name: 'pp_predict', label: 'Predict' },
                         { name: 'ml_evaluation', label: 'Evaluation', useApp: true },
@@ -134,7 +136,22 @@ define([
             }
 
             // menu libraries for ml 
-            let libObj = JSON.parse(librariesJson);
+            let libObj = {};
+            if (vpConfig.extensionType === 'lab' || vpConfig.extensionType === 'lite') {
+                libObj = librariesJson;
+
+                this.MlAppComponent = {};
+                this.MlAppComponent['ml_dataSplit'] = require('./dataSplit');
+                this.MlAppComponent['ml_dataPrep'] = require('./DataPrep');
+                this.MlAppComponent['ml_regression'] = require('./Regression');
+                this.MlAppComponent['ml_classification'] = require('./Classification');
+                this.MlAppComponent['ml_clustering'] = require('./Clustering');
+                this.MlAppComponent['ml_dimensionReduction'] = require('./DimensionReduction');
+                this.MlAppComponent['ml_gridSearch'] = require('./GridSearch');
+                this.MlAppComponent['ml_evaluation'] = require('./evaluation');
+            } else {
+                libObj = JSON.parse(librariesJson);
+            }
             this.mlAppList = libObj.library.item.filter(x => x.id === 'pkg_ml')[0].item;
             
             this.modelConfig = ML_LIBRARIES;
@@ -169,6 +186,8 @@ define([
                 $(that.wrapSelector('.vp-pp-step-content')).html('');
                 $(that.wrapSelector('.vp-pp-step-title')).text('');
                 that.state.pipeline = [];
+                $(that.wrapSelector('.vp-pp-step-prev')).addClass('disabled');
+                $(that.wrapSelector('.vp-pp-step-next')).addClass('disabled');
                 
                 that.handleChangeTemplate(type);
             }); 
@@ -177,7 +196,7 @@ define([
             $(document).on('click', this.wrapSelector('.vp-pp-item[data-flag="enabled"]'), function() {
                 if (!$(this).hasClass('selected')) {
                     let title = $(this).data('label');
-                    let stepSeq = parseInt($(this).data('seq')); // 0 ~ n
+                    let stepSeq = parseInt($(this).data('step')); // 0 ~ n
                     let name = $(this).data('name');
                     let ppObj = that.state.pipeline[stepSeq];
                     // set title
@@ -195,6 +214,20 @@ define([
                     // check selected
                     $(that.wrapSelector('.vp-pp-item')).removeClass('selected');
                     $(this).addClass('selected');
+
+                    // check prev/next
+                    let prevTagList = $(this).prevAll('.vp-pp-item[data-flag="enabled"]:visible');
+                    let nextTagList = $(this).nextAll('.vp-pp-item[data-flag="enabled"]:visible');
+                    if (prevTagList.length == 0) {
+                        $(that.wrapSelector('.vp-pp-step-prev')).addClass('disabled');
+                    } else {
+                        $(that.wrapSelector('.vp-pp-step-prev')).removeClass('disabled');
+                    }
+                    if (nextTagList.length == 0) {
+                        $(that.wrapSelector('.vp-pp-step-next')).addClass('disabled');
+                    } else {
+                        $(that.wrapSelector('.vp-pp-step-next')).removeClass('disabled');
+                    }
                 }
             });
 
@@ -217,6 +250,25 @@ define([
                     $(that.wrapSelector('.vp-pp-step-title')).text('');
                     $(that.wrapSelector(`.vp-pp-step-page[data-name="${name}"]`)).hide();
                     $(itemTag).removeClass('selected');
+
+                    // disable prev/next
+                    $(that.wrapSelector('.vp-pp-step-prev')).addClass('disabled');
+                    $(that.wrapSelector('.vp-pp-step-next')).addClass('disabled');
+                } else {
+                    // check prev/next
+                    let selectedTag = $(that.wrapSelector('.vp-pp-item.selected'));
+                    let prevTagList = $(selectedTag).prevAll('.vp-pp-item[data-flag="enabled"]:visible');
+                    let nextTagList = $(selectedTag).nextAll('.vp-pp-item[data-flag="enabled"]:visible');
+                    if (prevTagList.length == 0) {
+                        $(that.wrapSelector('.vp-pp-step-prev')).addClass('disabled');
+                    } else {
+                        $(that.wrapSelector('.vp-pp-step-prev')).removeClass('disabled');
+                    }
+                    if (nextTagList.length == 0) {
+                        $(that.wrapSelector('.vp-pp-step-next')).addClass('disabled');
+                    } else {
+                        $(that.wrapSelector('.vp-pp-step-next')).removeClass('disabled');
+                    }
                 }
 
             });
@@ -224,26 +276,75 @@ define([
             // model type change event
             $(document).on('change', this.wrapSelector(`#modelType`), function() {
                 let name = $(this).closest('.vp-pp-step-page').data('name');
-                
-                let modelType = $(this).val();
-                let modelObj = that.modelConfig[modelType];
-                let modelTypeName = modelObj.code.split('(')[0];
-                
-                that.state.modelType = modelType;
-                that.state.modelTypeName = modelTypeName;
+                let modelCreatorList = ['ml_dataPrep', 'ml_regression', 'ml_classification', 'ml_clustering', 'ml_dimensionReduction', 'ml_gridSearch'];
+                if (modelCreatorList.includes(name)) {
+                    let modelType = $(this).val();
+                    let modelObj = that.modelConfig[modelType];
+                    let modelTypeName = modelObj.returnType;
+                    
+                    that.state.modelType = modelType;
+                    that.state.modelTypeName = modelTypeName;
+                    
+                    // show fit / predict / transform depends on model selection
+                    let defaultActions = ['fit', 'predict', 'transform', 'fit_predict', 'fit_transform'];
+                    let actions = that.modelEditor.getAction(modelTypeName);
+                    defaultActions.forEach(actKey => {
+                        if (actions[actKey] === undefined) {
+                            // if undefined, hide step
+                            $(that.wrapSelector(`.vp-pp-item[data-name="pp_${actKey}"]`)).hide();
+                        } else {
+                            $(that.wrapSelector(`.vp-pp-item[data-name="pp_${actKey}"]`)).show();
+                            if (actKey === 'fit_predict') {
+                                if (actions['fit'] === undefined || actions['predict'] === undefined) {
+                                    $(that.wrapSelector(`.vp-pp-item[data-name="pp_fit"]`)).hide();
+                                    $(that.wrapSelector(`.vp-pp-item[data-name="pp_predict"]`)).hide();
+                                } else {
+                                    $(that.wrapSelector(`.vp-pp-item[data-name="pp_${actKey}"]`)).hide();
+                                }
+                            } else if (actKey === 'fit_transform') {
+                                if (actions['fit'] === undefined || actions['transform'] === undefined) {
+                                    $(that.wrapSelector(`.vp-pp-item[data-name="pp_fit"]`)).hide();
+                                    $(that.wrapSelector(`.vp-pp-item[data-name="pp_transform"]`)).hide();
+                                } else {
+                                    $(that.wrapSelector(`.vp-pp-item[data-name="pp_${actKey}"]`)).hide();
+                                }
+                            }
+                        }
+                        $(that.wrapSelector('.vp-pp-item')).removeClass('vp-last-visible');
+                        $(that.wrapSelector('.vp-pp-item:visible:last')).addClass('vp-last-visible');
+                    });
 
-                // show fit / predict / transform depends on model selection
-                let defaultActions = ['fit', 'predict', 'transform'];
-                let actions = that.modelEditor.getAction(modelTypeName);
-                defaultActions.forEach(actKey => {
-                    if (actions[actKey] === undefined) {
-                        // if undefined, hide step
-                        $(that.wrapSelector(`.vp-pp-item[data-name="pp_${actKey}"]`)).hide();
-                    } else {
-                        $(that.wrapSelector(`.vp-pp-item[data-name="pp_${actKey}"]`)).show();
+                    // change evaluation page's default selection
+                    if (name === 'ml_gridSearch') {
+                        let modelCategory = that.modelEditor.getModelCategory(modelTypeName); // Regression / Classification / Clustering
+                        let evalModelTypeValue = 'rgs';
+                        switch (modelCategory) {
+                            case 'Regression':
+                                evalModelTypeValue = 'rgs';
+                                break;
+                            case 'Classification':
+                                evalModelTypeValue = 'clf';
+                                break;
+                            case 'Clustering':
+                                evalModelTypeValue = 'cls';
+                                break;
+                        }
+                        let evalPageTag = $(that.wrapSelector('.vp-pp-step-page[data-name="ml_evaluation"]'));
+                        if (evalPageTag.is(':empty') === true) {
+                            // evaluation page is not opened yet
+                            // set state for evaluation page
+                            let stepSeq = $(evalPageTag).data('step');
+                            let ppObj = that.state.pipeline[stepSeq];
+                            if (ppObj.app) {
+                                ppObj.app.state.modelType = evalModelTypeValue;
+                            }
+                        } else {
+                            let evalModelTypeTag = $(evalPageTag).find('#modelType');
+                            $(evalModelTypeTag).val(evalModelTypeValue);
+                            $(evalModelTypeTag).trigger('change');
+                        }
                     }
-                });
-                
+                }
             });
 
             // model allocation variable change
@@ -252,6 +353,20 @@ define([
                 let modelAllocation = $(this).val();
                 that.state.model = modelAllocation;
             });
+
+            // click prev button
+            $(this.wrapSelector('.vp-pp-step-prev:not(.disabled)')).on('click', function() {
+                let selectedTag = $(that.wrapSelector('.vp-pp-item.selected'));
+                let prevTagList = $(selectedTag).prevAll('.vp-pp-item[data-flag="enabled"]:visible');
+                $(prevTagList[0]).trigger('click');
+            });
+
+            // click next button
+            $(this.wrapSelector('.vp-pp-step-next:not(.disabled)')).on('click', function() {
+                let selectedTag = $(that.wrapSelector('.vp-pp-item.selected'));
+                let nextTagList = $(selectedTag).nextAll('.vp-pp-item[data-flag="enabled"]:visible')
+                $(nextTagList[0]).trigger('click');
+            });
         }
 
         /**
@@ -268,8 +383,8 @@ define([
                 let appFileList = [];
                 // load pipeline items
                 tplObj.step.forEach((stepObj, idx) => {
-                    let { name, label, useApp=false, state={} } = stepObj;
-                    ppTag.appendFormatLine(`<div class="vp-pp-item" data-flag="enabled" data-name="{0}" data-seq="{1}" data-label="{2}">
+                    let { name, label, useApp=false, child=[], state={} } = stepObj;
+                    ppTag.appendFormatLine(`<div class="vp-pp-item" data-flag="enabled" data-name="{0}" data-step="{1}" data-label="{2}">
                         <span>{3}</span>
                         <div class="vp-pp-item-menu">
                             <label><input type="checkbox" class="vp-toggle vp-pp-item-toggle" checked/><span></span></label>
@@ -280,7 +395,7 @@ define([
                     if (useApp === true) {
                         let mlObj = that.mlAppList.filter(x => x.id === name)[0];
                         if (vpConfig.extensionType === 'lab' || vpConfig.extensionType === 'lite') {
-                            appFileList.push({ index: idx, name: name, file: './' + mlObj.file});
+                            appFileList.push({ index: idx, name: name, file: 'vp_base/js/' + mlObj.file});
                         } else {
                             appFileList.push({ index: idx, name: name, file: 'vp_base/js/' + mlObj.file});
                         }
@@ -293,6 +408,7 @@ define([
                     };
                     if (tplObj.modelStep === idx) {
                         pipeObj.modelStep = true;
+                        pipeObj.child = child;
                     }
                     that.state.pipeline.push(pipeObj);
                     // append pages
@@ -311,14 +427,15 @@ define([
                 // for lite and lab
                 if (vpConfig.extensionType === 'lab' || vpConfig.extensionType === 'lite') {
                     appFileList.forEach((obj, argIdx) => {
-                        let MlComponent = require(obj.file);
+                        let MlComponent = that.MlAppComponent[obj.name];
                         if (MlComponent) {
                             // DUP AREA: pp-1
-                            let { name, label, index, file } = obj;
+                            let { name, index, file } = obj;
                             let mlComponent = new MlComponent({ 
-                                config: { id: name, name: label, path: file, category: 'Pipeline', resizable: false },
+                                config: { id: name, name: that.state.pipeline[index].label, path: file, category: 'Pipeline', resizable: false },
                                     ...that.state.pipeline[index].state
                             });
+                            mlComponent.loadState();
                             // mlComponent.open($(that.wrapSelector(`.vp-pp-step-page[data-name="${appId}"]`)));
                             that.state.pipeline[index].app = mlComponent;
 
@@ -328,12 +445,17 @@ define([
                                 that.state.modelType = mlComponent.state.modelType;
                                 let modelObj = that.modelConfig[that.state.modelType];
                                 that.state.modelTypeName = modelObj.code.split('(')[0];
+
+                                that.state.pipeline[index].child.forEach(childId => {
+                                    that.renderApp(childId);
+                                });
                             }
                             // handle app view
                             that.handleAppView(name, mlComponent);
 
                             // select first step
-                            $(that.wrapSelector('.vp-pp-item[data-seq="0"]')).click();
+                            $(that.wrapSelector('.vp-pp-item[data-step="0"]')).click();
+                            $(that.wrapSelector('#modelType')).trigger('change');
                             // end of DUP AREA: pp-1
                         }
                     });
@@ -345,25 +467,32 @@ define([
                             let MlComponent = arguments[argIdx];
                             if (MlComponent) {
                                 // DUP AREA: pp-1
-                                let { name, label, index, file } = obj;
+                                let { name, index, file } = obj;
                                 let mlComponent = new MlComponent({ 
-                                    config: { id: name, name: label, path: file, category: 'Pipeline', resizable: false },
+                                    config: { id: name, name: that.state.pipeline[index].label, path: file, category: 'Pipeline', resizable: false },
                                         ...that.state.pipeline[index].state
                                 });
+                                mlComponent.loadState();
                                 // mlComponent.open($(that.wrapSelector(`.vp-pp-step-page[data-name="${appId}"]`)));
                                 that.state.pipeline[index].app = mlComponent;
 
                                 if (that.state.pipeline[index].modelStep === true) {
                                     // set default model type
+                                    that.state.model = mlComponent.state.allocateToCreation;
                                     that.state.modelType = mlComponent.state.modelType;
                                     let modelObj = that.modelConfig[that.state.modelType];
                                     that.state.modelTypeName = modelObj.code.split('(')[0];
+
+                                    that.state.pipeline[index].child.forEach(childId => {
+                                        that.renderApp(childId);
+                                    });
                                 }
                                 // handle app view
                                 that.handleAppView(name, mlComponent);
 
                                 // select first step
-                                $(that.wrapSelector('.vp-pp-item[data-seq="0"]')).click();
+                                $(that.wrapSelector('.vp-pp-item[data-step="0"]')).click();
+                                $(that.wrapSelector('#modelType')).trigger('change');
                                 // end of DUP AREA: pp-1
                             }
                         })
@@ -409,6 +538,9 @@ define([
             // load state
             if (this.state.templateType !== '') {
                 $(this.wrapSelector('#templateType')).trigger('change');
+            } else {
+                $(this.wrapSelector('.vp-pp-step-prev')).addClass('disabled');
+                $(this.wrapSelector('.vp-pp-step-next')).addClass('disabled');
             }
         }
 
@@ -442,6 +574,12 @@ define([
                 case 'pp_transform':
                     tag = this.templateForOptionPage(actions['transform']);
                     break;
+                case 'pp_fit_predict':
+                    tag = this.templateForOptionPage(actions['fit_predict']);
+                    break;
+                case 'pp_fit_transform':
+                    tag = this.templateForOptionPage(actions['fit_transform']);
+                    break;
             }
             $(this.wrapSelector(`.vp-pp-step-page[data-name="${appId}"]`)).html(`
                 <div class="vp-grid-border-box vp-grid-col-110">${tag}</div>
@@ -460,12 +598,69 @@ define([
                 label = com_util.optionToLabel(label);
                 optBox.appendFormatLine('<label for="{0}" title="{1}">{2}</label>'
                     , opt.name, opt.name, label);
-                let content = com_generator.renderContent(this, opt.component[0], opt, this.state);
+                let tmpState = {};
+                if (opt.value && opt.value !== '') {
+                    tmpState[opt.name] = opt.value;
+                }
+                let content = com_generator.renderContent(this, opt.component[0], opt, tmpState);
                 optBox.appendLine(content[0].outerHTML);
             });
             return optBox.toString();
         }
 
+        checkBeforeRun() {
+            let that = this;
+            var result = true;
+            for (let idx = 0; idx < this.state.pipeline.length; idx++) {
+                let ppObj = this.state.pipeline[idx];
+                var { name, label, useApp, app } = ppObj;
+                let requiredList = [];
+                result = true;
+                let isVisible = $(that.wrapSelector(`.vp-pp-item[data-step="${idx}"]`)).is(':visible') === true;
+                let isEnabled = $(that.wrapSelector(`.vp-pp-item[data-step="${idx}"]`)).attr('data-flag') === 'enabled';
+                if (isVisible && isEnabled) {
+                    switch (name) {
+                        case 'ml_dataSplit':
+                            requiredList = ['featureData', 'targetData'];
+                            // check required data
+                            for (let i = 0; i < requiredList.length; i++) {
+                                let reqKey = requiredList[i];
+                                result = that._checkIsEmpty($(app.wrapSelector('#' + reqKey)));
+                                if (result === false) {
+                                    // show page and focus it
+                                    $(that.wrapSelector(`.vp-pp-item[data-name="${name}"]`)).click();
+                                    $(app.wrapSelector('#' + reqKey)).focus();
+                                    break;
+                                }
+                            }
+                            break;
+                        case 'ml_gridSearch':
+                            result = app.checkBeforeRun();
+                            if (result === false) {
+                                // show page
+                                $(that.wrapSelector(`.vp-pp-item[data-name="${name}"]`)).click();
+                                break;
+                            }
+                            break;
+                    }
+                }
+                if (result === false) {
+                    break;
+                }
+            }
+            return result;
+
+        }
+
+        _checkIsEmpty(tag) {
+            let requiredFilled = true;
+            // if it's empty, focus on it
+            if (tag && $(tag) && $(tag).val() == '') {
+                requiredFilled = false;
+            }
+            return requiredFilled;
+        }
+
         generateCodeForOptionPage(appId) {
             let actions = this.modelEditor.getAction(this.state.modelTypeName);
             let actObj = {};
@@ -479,6 +674,12 @@ define([
                 case 'pp_transform':
                     actObj = actions['transform'];
                     break;
+                case 'pp_fit_predict':
+                    actObj = actions['fit_predict'];
+                    break;
+                case 'pp_fit_transform':
+                    actObj = actions['fit_transform'];
+                    break;
             }
 
             let code = new com_String();
@@ -513,25 +714,37 @@ define([
                 let { name, label, useApp, app } = ppObj;
                 
                 // check disabled
-                let isVisible = $(that.wrapSelector(`.vp-pp-item[data-seq="${idx}"]`)).is(':visible') === true;
-                let isEnabled = $(that.wrapSelector(`.vp-pp-item[data-seq="${idx}"]`)).data('flag') === 'enabled';
+                let isVisible = $(that.wrapSelector(`.vp-pp-item[data-step="${idx}"]`)).is(':visible') === true;
+                let isEnabled = $(that.wrapSelector(`.vp-pp-item[data-step="${idx}"]`)).attr('data-flag') === 'enabled';
                 if (isVisible && isEnabled) {
                     if (code.toString() !== '') {
                         code.appendLine();
                         code.appendLine();
                     }
-                    code.appendFormatLine("# [{0}] {1}", stepNo, label);
                     if (useApp) {
-                        code.append(app.generateCode());
+                        let appCode = app.generateCode();
+                        if (appCode instanceof Array) {
+                            appCode = appCode.join('\n');
+                        }
+                        if (appCode && appCode.trim() !== '') {
+                            code.appendFormatLine("# [{0}] {1}", stepNo++, label);
+                            if (name === 'ml_evaluation') {
+                                // import auto generate
+                                code.appendLine(app.generateImportCode().join('\n'));
+                            }
+                            code.append(appCode);
+                        }
                         // save state
                         that.state.pipeline[idx].state = app.state;
                     } else {
                         let ppResult = that.generateCodeForOptionPage(name);
-                        code.append(ppResult.code);
+                        if (ppResult && ppResult?.code?.trim() !== '') {
+                            code.appendFormatLine("# [{0}] {1}", stepNo++, label);
+                            code.append(ppResult.code);
+                        }
                         // save state
                         that.state.pipeline[idx].state = ppResult.state;
                     }
-                    stepNo++;
                 }
             });
 
