@@ -160,7 +160,12 @@ define([
         }
 
         generateInstallCode() {
-            return [ '!pip install factor-analyzer'];
+            let installCode = '!pip install factor-analyzer';
+            // Add installation code
+            if (vpConfig.extensionType === 'lite') {
+                installCode = '%pip install factor-analyzer';
+            }
+            return [ installCode ];
         }
 
         generateCode() {
@@ -168,13 +173,6 @@ define([
             let codeList = [];
             let code = new com_String();
 
-            // Add installation code FIXME:
-            if (vpConfig.extensionType === 'lite') {
-                codeList.push('%pip install factor-analyzer');
-            } else {
-                codeList.push('!pip install factor-analyzer');
-            }
-
             // data declaration
             code.appendFormat("vp_df = {0}", data);
             if (this.columnSelector) {
